${header}
namespace Boo.Lang.Compiler.Ast
{
	using System;

	public partial class ${node.Name}
	{
		public ${node.Name}()
		{
		}
		
		public ${node.Name}(LexicalInfo lexicalInfo) : base(lexicalInfo)
		{
		}
	}
}

